| Title: | EPA Fuel Economy Data |
|---|---|
| Description: | Fuel economy data from the EPA, 1985-2015, conveniently packaged for consumption by R users. |
| Authors: | Hadley Wickham [aut, cre] |
| Maintainer: | Hadley Wickham <[email protected]> |
| License: | CC0 |
| Version: | 1.0.0.9000 |
| Built: | 2026-05-11 06:41:17 UTC |
| Source: | https://github.com/hadley/fueleconomy |
These models have at least 10 years worth of data. This dataset is suitable for a left-join designed to restrict the number of observations to a more manageable level.
commoncommon
A dataset with variables make, model, n (total number of models) and years (total number of model-years).
if (require("dplyr")) { vehicles %>% semi_join(common) }if (require("dplyr")) { vehicles %>% semi_join(common) }
Fuel economy data from the EPA, 1985-2015. This dataset contains selected varaibles, and removes vehicles with incomplete data (e.g. no drive train data)
vehiclesvehicles
A data frame with variables:
Unique EPA identifier
Manufacturer
Model name
Model year
EPA vehicle size class, http://www.fueleconomy.gov/feg/ws/wsData.shtml#VClass
Transmission
Drive train
Number of cylinders
Engine displacement, in litres
Fuel type
Highway fuel economy, in mpg
City fuel economy, in mpg
http://www.fueleconomy.gov/feg/download.shtml
if (require("dplyr")) { vehicles vehicles %>% group_by(year) %>% summarise(cty = mean(cty)) }if (require("dplyr")) { vehicles vehicles %>% group_by(year) %>% summarise(cty = mean(cty)) }